@@ -608,6 +608,7 @@ class Gateway:
             cluster_name,
             shutdown_on_close=shutdown_on_close,
             address=self.address,
+            public_address=self._public_address,
             proxy_address=self.proxy_address,
             auth=self.auth,
             asynchronous=self.asynchronous,
@@ -1011,7 +1012,7 @@ class GatewayCluster:
         if self._watch_worker_status_task is not None:
             await cancel_task(self._watch_worker_status_task)
         if self.scheduler_comm is not None:
-            self.scheduler_comm.close_rpc()
+            await self.scheduler_comm.close_rpc()
         for client in list(self._clients):
             await client._close()
             self._clients.discard(client)
@@ -1222,7 +1223,11 @@ class GatewayCluster:
     def _ipython_display_(self, **kwargs):
         widget = self._widget()
         if widget is not None:
-            return widget._ipython_display_(**kwargs)
+            # ipywidgets renamed the _ipython_display_ method in 8.x
+            try:
+                return widget._ipython_display_(**kwargs)
+            except AttributeError:
+                return widget._repr_mimebundle_(**kwargs)
         else:
             from IPython.display import display
 
